# package_name

Description. 
The package package_name is used to:
	Processing:
		- Histogram matching
		- Structural similariy
		- Resize Image:
	Utils:
		- Read Image
		- Save Image
		- Plot Image
		- Plot result
		- Plot histogram

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install image_processing

```bash
pip install image_processing_nferepa01
```

## Usage

```python
from package_name.module1_name import file1_name
file1_name.my_function()
```

## Author
Nicholas and Karina

## License
[MIT](https://choosealicense.com/licenses/mit/)